==> osidb_bindings-4.10.1.tar.gz: osidb_bindings-4.10.1/osidb_bindings/bindings/python_client/models/collectors_api_v1_status_retrieve_response_200.py <==
import datetime
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, OSIDBModel, Unset

if TYPE_CHECKING:
    from ..models.collectors_api_v1_status_retrieve_response_200_collectors_item import (
        CollectorsApiV1StatusRetrieveResponse200CollectorsItem,
    )


T = TypeVar("T", bound="CollectorsApiV1StatusRetrieveResponse200")


@_attrs_define
class CollectorsApiV1StatusRetrieveResponse200(OSIDBModel):
    """
    Attributes:
        collectors (Union[Unset, list['CollectorsApiV1StatusRetrieveResponse200CollectorsItem']]):
        dt (Union[Unset, datetime.datetime]):
        env (Union[Unset, str]):
        revision (Union[Unset, str]):
        version (Union[Unset, str]):
    """

    collectors: Union[
        Unset, list["CollectorsApiV1StatusRetrieveResponse200CollectorsItem"]
    ] = UNSET
    dt: Union[Unset, datetime.datetime] = UNSET
    env: Union[Unset, str] = UNSET
    revision: Union[Unset, str] = UNSET
    version: Union[Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        collectors: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.collectors, Unset):
            collectors = []
            for collectors_item_data in self.collectors:
                collectors_item: dict[str, Any] = UNSET
                if not isinstance(collectors_item_data, Unset):
                    collectors_item = collectors_item_data.to_dict()

                collectors.append(collectors_item)

        dt: Union[Unset, str] = UNSET
        if not isinstance(self.dt, Unset):
            dt = self.dt.isoformat()

        env = self.env

        revision = self.revision

        version = self.version

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if not isinstance(collectors, Unset):
            field_dict["collectors"] = collectors
        if not isinstance(dt, Unset):
            field_dict["dt"] = dt
        if not isinstance(env, Unset):
            field_dict["env"] = env
        if not isinstance(revision, Unset):
            field_dict["revision"] = revision
        if not isinstance(version, Unset):
            field_dict["version"] = version

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        from ..models.collectors_api_v1_status_retrieve_response_200_collectors_item import (
            CollectorsApiV1StatusRetrieveResponse200CollectorsItem,
        )

        d = src_dict.copy()
        collectors = []
        _collectors = d.pop("collectors", UNSET)
        for collectors_item_data in _collectors or []:
            _collectors_item = collectors_item_data
            collectors_item: CollectorsApiV1StatusRetrieveResponse200CollectorsItem
            if isinstance(_collectors_item, Unset):
                collectors_item = UNSET
            else:
                collectors_item = (
                    CollectorsApiV1StatusRetrieveResponse200CollectorsItem.from_dict(
                        _collectors_item
                    )
                )

            collectors.append(collectors_item)

        _dt = d.pop("dt", UNSET)
        dt: Union[Unset, datetime.datetime]
        if isinstance(_dt, Unset):
            dt = UNSET
        else:
            dt = isoparse(_dt)

        env = d.pop("env", UNSET)

        revision = d.pop("revision", UNSET)

        version = d.pop("version", UNSET)

        collectors_api_v1_status_retrieve_response_200 = cls(
            collectors=collectors,
            dt=dt,
            env=env,
            revision=revision,
            version=version,
        )

        collectors_api_v1_status_retrieve_response_200.additional_properties = d
        return collectors_api_v1_status_retrieve_response_200

    @staticmethod
    def get_fields():
        return {
            "collectors": list[
                "CollectorsApiV1StatusRetrieveResponse200CollectorsItem"
            ],
            "dt": datetime.datetime,
            "env": str,
            "revision": str,
            "version": str,
        }

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> osidb_bindings-5.0.0b3.tar.gz: osidb_bindings-5.0.0b3/osidb_bindings/bindings/python_client/models/collectors_api_v1_status_retrieve_response_200.py <==
import datetime
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from attrs import fields as _attrs_fields
from dateutil.parser import isoparse

from ..types import UNSET, OSIDBModel, Unset

if TYPE_CHECKING:
    from ..models.collectors_api_v1_status_retrieve_response_200_collectors_item import (
        CollectorsApiV1StatusRetrieveResponse200CollectorsItem,
    )


T = TypeVar("T", bound="CollectorsApiV1StatusRetrieveResponse200")


@_attrs_define
class CollectorsApiV1StatusRetrieveResponse200(OSIDBModel):
    """
    Attributes:
        collectors (Union[Unset, list['CollectorsApiV1StatusRetrieveResponse200CollectorsItem']]):
        dt (Union[Unset, datetime.datetime]):
        env (Union[Unset, str]):
        revision (Union[Unset, str]):
        version (Union[Unset, str]):
    """

    collectors: Union[
        Unset, list["CollectorsApiV1StatusRetrieveResponse200CollectorsItem"]
    ] = UNSET
    dt: Union[Unset, datetime.datetime] = UNSET
    env: Union[Unset, str] = UNSET
    revision: Union[Unset, str] = UNSET
    version: Union[Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        collectors: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.collectors, Unset):
            collectors = []
            for collectors_item_data in self.collectors:
                collectors_item: dict[str, Any] = UNSET
                if not isinstance(collectors_item_data, Unset):
                    collectors_item = collectors_item_data.to_dict()

                collectors.append(collectors_item)

        dt: Union[Unset, str] = UNSET
        if not isinstance(self.dt, Unset):
            dt = self.dt.isoformat()

        env = self.env

        revision = self.revision

        version = self.version

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if not isinstance(collectors, Unset):
            field_dict["collectors"] = collectors
        if not isinstance(dt, Unset):
            field_dict["dt"] = dt
        if not isinstance(env, Unset):
            field_dict["env"] = env
        if not isinstance(revision, Unset):
            field_dict["revision"] = revision
        if not isinstance(version, Unset):
            field_dict["version"] = version

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        from ..models.collectors_api_v1_status_retrieve_response_200_collectors_item import (
            CollectorsApiV1StatusRetrieveResponse200CollectorsItem,
        )

        d = src_dict.copy()
        collectors = []
        _collectors = d.pop("collectors", UNSET)
        for collectors_item_data in _collectors or []:
            _collectors_item = collectors_item_data
            collectors_item: CollectorsApiV1StatusRetrieveResponse200CollectorsItem
            if isinstance(_collectors_item, Unset):
                collectors_item = UNSET
            else:
                collectors_item = (
                    CollectorsApiV1StatusRetrieveResponse200CollectorsItem.from_dict(
                        _collectors_item
                    )
                )

            collectors.append(collectors_item)

        _dt = d.pop("dt", UNSET)
        dt: Union[Unset, datetime.datetime]
        if isinstance(_dt, Unset):
            dt = UNSET
        else:
            dt = isoparse(_dt)

        env = d.pop("env", UNSET)

        revision = d.pop("revision", UNSET)

        version = d.pop("version", UNSET)

        collectors_api_v1_status_retrieve_response_200 = cls(
            collectors=collectors,
            dt=dt,
            env=env,
            revision=revision,
            version=version,
        )

        collectors_api_v1_status_retrieve_response_200.additional_properties = d
        return collectors_api_v1_status_retrieve_response_200

    @classmethod
    def get_fields(cls):
        return {f.name: f.type for f in _attrs_fields(cls)}

    @classmethod
    def new(cls):
        return cls.from_dict({})

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
